@@ -42,6 +42,8 @@ from ..rest import (
     create_order_factory,
     get_user_balance_factory,
     get_user_open_orders_factory,
+    get_user_trades_http,
+    get_user_trades_factory,
 )
 
 from ..models import BookConfig, CryptodotcomContext
@@ -114,6 +116,8 @@ def get_framework(
         create_order=create_order_factory(private_messages, exchange, socket_bs),
         exchange=exchange,
         feed_messages=feed_messages,
+        get_user_trades=get_user_trades_factory(response_messages, socket_bs),
+        get_user_trades_http=get_user_trades_http(add_token_http),
         get_user_balance=get_user_balance_factory(response_messages, socket_bs),
         get_user_open_orders=get_user_open_orders,
         guaranteed_websocket=guaranteed_socket,
