@@ -14,7 +14,7 @@ from .bundle import WebsocketBundle
 from .user_balance import (
     UserBalance,
 )
-
+from .trade import Trade
 from .order import OrderDict
 
 
@@ -44,6 +44,8 @@ class CryptodotcomContext:
     ]
     exchange: cryptocom
     feed_messages: Observable[CryptodotcomResponseMessage]
+    get_user_trades: Callable[[str, int], Observable[list[Trade]]]
+    get_user_trades_http: Callable[[str, int], Observable[list[Trade]]]
     get_user_balance: Callable[[], Observable[list[UserBalance]]]
     get_user_open_orders: Callable[[Optional[str]], Observable[list[OrderDict]]]
     guaranteed_websocket: Observable[EnhancedWebsocket]
