@@ -13,11 +13,16 @@ from reactivex.scheduler import NewThreadScheduler
 def order_confirmation(
     messages: Observable[CryptodotcomResponseMessage],
     order_id: str,
+    client_order_id: str,
 ):
     def is_match(message: CryptodotcomResponseMessage) -> bool:
         try:
             data = message.result["data"][0]
-            return data["order_id"] == order_id and data["status"] == "canceled"
+            if order_id and data["order_id"] != order_id:
+                return False
+            if client_order_id and data["client_oid"] !=  client_order_id:
+                return False
+            return data["status"] == "canceled"
         except:
             return False
 
@@ -31,7 +36,7 @@ def order_confirmation(
 def cancel_order_factory(
     messages: Observable[CryptodotcomResponseMessage],
     socket: EnhancedWebsocketBehaviorSubject,
-) -> Callable[[str, bool | None, bool | None], Observable[bool]]:
+) -> Callable[[str, str | None, bool | None, bool | None], Observable[bool]]:
     """Factory for cancel order API call
 
     Args:
@@ -45,15 +50,23 @@ def cancel_order_factory(
 
     """
 
-    def cancel_order(order_id: str, wait_for_confirmation=True, ignore_errors=True):
-        request = {"order_id": order_id}
+    def cancel_order(order_id: str="", client_order_id: str | None="", wait_for_confirmation=True, ignore_errors=True):
+        if order_id:
+            request = {"order_id": order_id}
+        elif client_order_id:
+            request = {"client_oid": client_order_id}
+        else:
+            return throw(ValueError('Either order_id or client_order_id is required'))
 
         def subscribe(observer, scheduler=None):
-            ws = socket.value
             recorded_messages = messages.pipe(
                 operators.replay(),
             )
-            sub = recorded_messages.connect(scheduler=NewThreadScheduler())
+
+            sub = recorded_messages.connect(scheduler=scheduler)
+            message_id, sender = socket.value.request_to_observable(
+                CryptodotcomRequestMessage(MethodName.CANCEL_ORDER, params=request)
+            )
 
             def on_cancel(x):
                 if x.code != 0 and not ignore_errors:
@@ -62,11 +75,8 @@ def cancel_order_factory(
 
             send_request = messages.pipe(
                 wait_for_response(
-                    ws.send_message(
-                        CryptodotcomRequestMessage(
-                            MethodName.CANCEL_ORDER, params=request
-                        )
-                    ),
+                    message_id,
+                    sender,
                     2.0,
                 )
             )
@@ -74,7 +84,7 @@ def cancel_order_factory(
                 successful_request = send_request.pipe(
                     operators.flat_map(on_cancel),
                     operators.flat_map(
-                        lambda x: order_confirmation(recorded_messages, order_id)
+                        lambda x: order_confirmation(recorded_messages, order_id, client_order_id or "")
                     ),
                     operators.catch(
                         lambda exc, _source: just(False)
