@@ -65,7 +65,7 @@ def close_position_factory(
 def close_position_http_factory(
     add_token: Callable[[requests.models.Request], requests.models.Request]
 ):
-    def cancel_all_http(
+    def close_position_http(
         pair: str, order_type: Literal["limit", "market"], price: str | None = ""
     ) -> Observable:
         params = {"instrument_name": pair, "type": order_type}
@@ -75,4 +75,4 @@ def close_position_http_factory(
         request = prepare_request(message)
         return send_request(add_token(request))
 
-    return cancel_all_http
+    return close_position_http
